@@ -1,4 +1,4 @@
-from datetime import date, timedelta
+from datetime import date, datetime, timedelta
 
 # Requirements:
 # * Convert from an ox date to a normal date                ox_to_normal
@@ -52,9 +52,28 @@ TERM_STARTS = {
     (2014, 2): date(2014, 4, 20),  # Easter Sunday?
     (2014, 3): date(2014, 10, 5),
     (2015, 1): date(2015, 1, 11),
-    (2015, 2): date(2015, 4, 19)
+    (2015, 2): date(2015, 4, 19),
+    (2015, 3): date(2015, 10, 4),
+    (2016, 1): date(2016, 1, 10),
+    (2016, 2): date(2016, 4, 17),
+# Provisional from here onwards
+    (2016, 3): date(2016, 10, 2),
+    (2017, 1): date(2017, 1, 8),
+    (2017, 2): date(2017, 4, 16),
+    (2017, 3): date(2017, 10, 1),
+    (2018, 1): date(2018, 1, 7),
+    (2018, 2): date(2018, 4, 15),
+    (2018, 3): date(2018, 9, 30),
+    (2019, 1): date(2019, 1, 6),
+    (2019, 2): date(2019, 4, 21),
+    (2019, 3): date(2019, 10, 6),
+    (2020, 1): date(2020, 1, 12),
+    (2020, 2): date(2020, 4, 19),
 }
 
+# Sanity check; all dates should be Sundays
+assert all(dt.isoweekday() == 7 for dt in TERM_STARTS.values())
+
 OFFSET_TERM_STARTS = dict((k, v-timedelta(14)) for k, v in TERM_STARTS.items())
 
 DAY_NAMES = [
@@ -96,7 +115,10 @@ def normal_to_ox(pdate):
 
 
 def ox_date_dict(dt=None):
-    dt = dt.date() if dt else date.today()
+    if dt is None:
+        dt = date.today()
+    elif isinstance(dt, datetime):
+        dt = dt.date()
     year, term, week, day = normal_to_ox(dt)
     return {
         'day_name': DAY_NAMES[day],
@@ -121,6 +143,12 @@ def format_date(date_dict):
     """
     return "%(day_name)s, %(week)d%(ordinal)s week, %(term_long)s %(year)d (%(day_number)d %(month)s)" % date_dict
 
+def format_date_nocal(date_dict):
+    """Format a date to "standard" Oxford format, but excluding the calendar date at the end
+    :param date_dict: date dict
+    :return: String
+    """
+    return "%(day_name)s, %(week)d%(ordinal)s week, %(term_long)s %(year)d" % date_dict
 
 def format_today():
     return format_date(ox_date_dict())
